import { Screen, Application } from '@nativescript/core';
/**
 * @deprecated. NativeScript introduced media queries in version 8.8. We've deprecated this package in favor of using @nativescript/core. Official documentation is available [here](https://docs.nativescript.org/guide/styling#media-queries-8-8)
 */
export const matchMedia = (mediaQueryString) => {
    const factory = MediaQueryListFactory.getInstance();
    const mql = factory.create(mediaQueryString);
    factory.updateMatches();
    return mql;
};
class MediaQueryListImpl {
    constructor(media) {
        this.media = media;
        this.listeners = new Set();
        this.matches = false;
        this.onchange = null;
    }
    addListener(listener) {
        this.listeners.add(listener);
    }
    removeListener(listener) {
        this.listeners.delete(listener);
    }
    dispatchChangeEvent() {
        const event = {
            matches: this.matches,
            media: this.media,
        };
        for (const listener of this.listeners) {
            listener(this);
        }
        if (typeof this.onchange === 'function') {
            this.onchange.call(this, event);
        }
    }
    updateMatches(matches) {
        if (this.matches !== matches) {
            this.matches = matches;
            this.dispatchChangeEvent();
        }
    }
}
class MediaQueryListFactory {
    constructor() {
        this.lists = [];
    }
    static getInstance() {
        if (!MediaQueryListFactory.instance) {
            MediaQueryListFactory.instance = new MediaQueryListFactory();
            // Condition for update
            Application.on('orientationChanged', () => {
                setTimeout(() => {
                    MediaQueryListFactory.instance.updateMatches();
                }, 10);
            });
        }
        return MediaQueryListFactory.instance;
    }
    create(media) {
        const mql = new MediaQueryListImpl(media);
        this.lists.push(mql);
        return mql;
    }
    remove(mql) {
        const index = this.lists.indexOf(mql);
        if (index > -1) {
            this.lists.splice(index, 1);
        }
    }
    updateMatches() {
        for (const mql of this.lists) {
            const queryParts = this.extractQueryParts(mql.media);
            const matches = this.checkMediaQuery(queryParts);
            mql.updateMatches(matches);
        }
    }
    extractQueryParts(mediaQuery) {
        const query = mediaQuery.trim().slice(1, -1);
        const parts = query.split(' and ');
        return parts.map((part) => part.replace('(', '').replace(')', '').trim());
    }
    checkMediaQuery(queryParts) {
        return queryParts.map((part) => evaluatePart(part)).every(Boolean);
    }
}
function evaluatePart(part) {
    const [property, value] = part.split(':');
    const trimmedProperty = property.trim();
    const trimmedValue = value.trim();
    if (trimmedProperty.includes('width') || trimmedProperty.includes('height')) {
        const realWidth = Screen.mainScreen.widthDIPs;
        const realHeight = Screen.mainScreen.heightDIPs;
        if (trimmedProperty === 'width') {
            return parseInt(realWidth.toString(), 10) === parseInt(trimmedValue, 10);
        }
        else if (trimmedProperty === 'min-width') {
            return realWidth >= parseInt(trimmedValue, 10);
        }
        else if (trimmedProperty === 'max-width') {
            return realWidth <= parseInt(trimmedValue, 10);
        }
        else if (trimmedProperty === 'height') {
            return parseInt(realHeight.toString(), 10) === parseInt(trimmedValue, 10);
        }
        else if (trimmedProperty === 'min-height') {
            return realHeight >= parseInt(trimmedValue, 10);
        }
        else if (trimmedProperty === 'max-height') {
            return realHeight <= parseInt(trimmedValue, 10);
        }
    }
    else if (trimmedProperty === 'orientation') {
        return Application.orientation() === trimmedValue;
    }
    else {
        // TBD
        return false;
    }
}
//# sourceMappingURL=index.js.map